@@ -2,5 +2,6 @@ frontegg_headers = {
     'vendor_host': 'frontegg-vendor-host',
     'tenant_id': 'frontegg-tenant-id',
     'user_id': 'frontegg-user-id',
-    'permissions': 'frontegg-user-permissions'
+    'permissions': 'frontegg-user-permissions',
+    'middleware_request': 'frontegg-middleware-request',
 }
\ No newline at end of file
